=================
Package Structure
=================

Here is `xhydro`'s structure as of v0.3.3 (2024-02-22), with the planned or discussed additions for the future.

Testing data can be found here: https://github.com/hydrologie/xhydro-testdata

.. image:: _static/_images/xhydro_structure.png
  :width: 800
